(() => {
  // src/module.ts
  var AddonModule = class {
    constructor(parent) {
      this._Addon = parent;
    }
  };
  var module_default = AddonModule;

  // src/events.ts
  var AddonEvents = class extends module_default {
    async onInit() {
      this.previewMode = "normal";
      this.previewSplitCollapsed = false;
      Zotero.debug("PDFPreview: init called");
      await Zotero.uiReadyPromise;
      if (!Zotero.Prefs.get("pdfpreview.enable")) {
        return;
      }
      this.initOverlay();
      this.initItemSelectListener();
      this.initPreviewResizeListener();
      this.initTabSelectListener();
      this.initPreviewInfoSplit();
      this.initPreviewAttachmentSplit();
      this.updatePreviewInfoSplit();
      this.updatePreviewAttachmentSplit();
      this.updatePreviewTab();
      let type = 1 /* info */;
      while (type !== 4 /* null */) {
        await this.initPreview(type);
        type++;
      }
    }
    initOverlay() {
      var _a, _b;
      const tab = document.createElement("tab");
      tab.id = "pdf-preview-tab";
      tab.setAttribute("label", Zotero.Prefs.get("pdfpreview.previewTabName"));
      (_a = document.getElementById("zotero-editpane-tabs")) == null ? void 0 : _a.appendChild(tab);
      const tabpanel = document.createElement("tabpanel");
      tabpanel.id = "pdf-preview-tabpanel";
      tabpanel.style.overflow = "hidden";
      (_b = document.getElementById("zotero-view-item")) == null ? void 0 : _b.appendChild(tabpanel);
    }
    unInitOverlay() {
      [
        "pdf-preview-tab",
        "pdf-preview-tabpanel",
        "pdf-preview-infosplit-before",
        "pdf-preview-infosplit-after",
        "pdf-preview-attachment-before",
        "pdf-preview-attachment-after"
      ].forEach((id) => {
        var _a;
        return (_a = document.getElementById(id)) == null ? void 0 : _a.remove();
      });
    }
    initItemSelectListener() {
      ZoteroPane.itemsView.onSelect.addListener(() => {
        console.log("Preview triggered by selection change");
        this.doPreview();
      });
    }
    initPreviewResizeListener() {
      const splitter = document.getElementById("zotero-items-splitter");
      const grippy = document.getElementById("zotero-items-grippy");
      const onResize = (e) => {
        console.log("Preview triggered by resize");
        this.doPreview(true);
      };
      splitter.addEventListener("mouseup", onResize);
      grippy.addEventListener("mouseup", (e) => {
        setTimeout(onResize, 10);
      });
    }
    initTabSelectListener() {
      const tabbox = document.querySelector("#zotero-view-tabbox");
      tabbox.addEventListener("command", (e) => {
        if (!["zotero-editpane-info-tab", "pdf-preview-tab"].includes(e.target.id)) {
          return;
        }
        console.log("Preview triggered by tab change");
        this.doPreview();
      });
    }
    doPreview(force = false) {
      this.updatePreviewTab();
      const previewType = this.getPreviewType();
      console.log(previewType);
      if (previewType === 1 /* info */) {
        this.updatePreviewInfoSplit();
      } else if (previewType === 3 /* attachment */) {
        this.updatePreviewAttachmentSplit();
      } else if (previewType === 4 /* null */) {
        return;
      }
      this._Addon.preview.preview(previewType, force);
    }
    getPreviewType() {
      const paneDeck = document.getElementById("zotero-item-pane-content");
      const selectedPane = paneDeck.selectedPanel;
      if (selectedPane.id === "zotero-view-tabbox") {
        const tabbox = document.getElementById("zotero-view-tabbox");
        const infoTab = document.getElementById("zotero-editpane-info-tab");
        if (tabbox.selectedTab === infoTab && !this.previewSplitCollapsed) {
          return 1 /* info */;
        }
        const previewTab = document.getElementById("pdf-preview-tab");
        if (tabbox.selectedTab === previewTab) {
          return 2 /* preview */;
        }
      } else if (selectedPane.querySelector("#zotero-attachment-box") && !this.previewSplitCollapsed) {
        return 3 /* attachment */;
      }
      return 4 /* null */;
    }
    updatePreviewTab() {
      const hidden = !Zotero.Prefs.get("pdfpreview.enableTab");
      const previewTab = document.querySelector("#pdf-preview-tab");
      if (hidden) {
        previewTab.style.visibility = "hidden";
      } else {
        previewTab.style.removeProperty("visibility");
      }
    }
    initPreviewInfoSplit(zitembox = void 0) {
      var _a;
      zitembox = zitembox || document.querySelector("#zotero-editpane-item-box");
      console.log(zitembox, zitembox.parentElement);
      (_a = zitembox.parentElement) == null ? void 0 : _a.setAttribute("orient", "vertical");
      const boxBefore = document.createElement("box");
      boxBefore.id = "pdf-preview-infosplit-before";
      const boxAfter = document.createElement("box");
      boxAfter.id = "pdf-preview-infosplit-after";
      zitembox.before(boxBefore);
      zitembox.after(boxAfter);
      const splitterBefore = document.createElement("splitter");
      splitterBefore.id = "pdf-preview-infosplit-splitter-before";
      splitterBefore.setAttribute("collapse", "before");
      const grippyBefore = document.createElement("grippy");
      splitterBefore.append(grippyBefore);
      splitterBefore.addEventListener("command", (e) => {
        this.setSplitHeight(document.querySelector("#pdf-preview-infosplit-before").getAttribute("height"));
        this.setSplitCollapsed(splitterBefore.getAttribute("state") === "collapsed");
      });
      boxBefore.after(splitterBefore);
      const splitterAfter = document.createElement("splitter");
      splitterAfter.id = "pdf-preview-infosplit-splitter-after";
      splitterAfter.setAttribute("collapse", "after");
      const grippyAfter = document.createElement("grippy");
      splitterAfter.append(grippyAfter);
      splitterAfter.addEventListener("command", (e) => {
        this.setSplitHeight(document.querySelector("#pdf-preview-infosplit-after").getAttribute("height"));
        this.setSplitCollapsed(splitterAfter.getAttribute("state") === "collapsed");
      });
      boxAfter.before(splitterAfter);
    }
    initPreviewAttachmentSplit(zitembox = void 0) {
      var _a;
      zitembox = zitembox || document.querySelector("#zotero-attachment-box");
      console.log(zitembox, zitembox.parentElement);
      (_a = zitembox.parentElement) == null ? void 0 : _a.setAttribute("orient", "vertical");
      const boxBefore = document.createElement("box");
      boxBefore.id = "pdf-preview-attachment-before";
      const boxAfter = document.createElement("box");
      boxAfter.id = "pdf-preview-attachment-after";
      zitembox.before(boxBefore);
      zitembox.after(boxAfter);
      const splitterBefore = document.createElement("splitter");
      splitterBefore.id = "pdf-preview-attachment-splitter-before";
      splitterBefore.setAttribute("collapse", "before");
      const grippyBefore = document.createElement("grippy");
      splitterBefore.append(grippyBefore);
      splitterBefore.addEventListener("command", (e) => {
        this.setSplitHeight(document.querySelector("#pdf-preview-attachment-before").getAttribute("height"));
        this.setSplitCollapsed(splitterBefore.getAttribute("state") === "collapsed");
      });
      boxBefore.after(splitterBefore);
      const splitterAfter = document.createElement("splitter");
      splitterAfter.id = "pdf-preview-attachment-splitter-after";
      splitterAfter.setAttribute("collapse", "after");
      const grippyAfter = document.createElement("grippy");
      splitterAfter.append(grippyAfter);
      splitterAfter.addEventListener("command", (e) => {
        this.setSplitHeight(document.querySelector("#pdf-preview-attachment-after").getAttribute("height"));
        this.setSplitCollapsed(splitterAfter.getAttribute("state") === "collapsed");
      });
      boxAfter.before(splitterAfter);
    }
    updatePreviewInfoSplit() {
      var _a;
      const BBTBox = (_a = document.getElementById("zotero-editpane-item-box").parentElement) == null ? void 0 : _a.querySelector("#better-bibtex-editpane-item-box");
      if (BBTBox && this.previewMode !== "BBT") {
        this.previewMode = "BBT";
        const toRemove = [
          "pdf-preview-infosplit-before",
          "pdf-preview-infosplit-after",
          "pdf-preview-infosplit-splitter-before",
          "pdf-preview-infosplit-splitter-after"
        ];
        toRemove.forEach((_id) => {
          const ele = document.getElementById(_id);
          if (ele) {
            ele.remove();
          }
        });
        console.log("re-init preview for BBT");
        this.initPreviewInfoSplit(BBTBox.parentElement);
        const tabbox = document.querySelector("#zotero-view-tabbox");
        const tabIndex = tabbox.selectedIndex;
        tabbox.selectedIndex = tabIndex === tabbox.childNodes.length - 1 ? 1 : tabIndex + 1;
        setTimeout(async () => {
          tabbox.selectedIndex = tabIndex;
          await this.initPreview(1 /* info */);
          this.doPreview(true);
        }, 1);
      }
      const hidden = !Zotero.Prefs.get("pdfpreview.enableSplit");
      const splitType = Zotero.Prefs.get("pdfpreview.splitType");
      const splitContainer = document.querySelector(`#pdf-preview-infosplit-${splitType}`);
      const splitSplitter = document.querySelector(`#pdf-preview-infosplit-splitter-${splitType}`);
      if (hidden) {
        splitContainer.setAttribute("height", "0");
        splitContainer.style.visibility = "hidden";
        splitSplitter.style.visibility = "hidden";
      } else {
        splitContainer.setAttribute("height", this.getSplitHeight());
        splitContainer.style.removeProperty("visibility");
        splitSplitter.style.removeProperty("visibility");
      }
      const hiddenType = splitType === "before" ? "after" : "before";
      const hiddenContainer = document.querySelector(`#pdf-preview-infosplit-${hiddenType}`);
      const hiddenSplitter = document.querySelector(`#pdf-preview-infosplit-splitter-${hiddenType}`);
      hiddenContainer.setAttribute("height", "0");
      hiddenContainer.style.visibility = "hidden";
      hiddenSplitter.style.visibility = "hidden";
    }
    updatePreviewAttachmentSplit() {
      const hidden = !Zotero.Prefs.get("pdfpreview.enableSplit");
      const splitType = Zotero.Prefs.get("pdfpreview.splitType");
      const splitContainer = document.querySelector(`#pdf-preview-attachment-${splitType}`);
      const splitSplitter = document.querySelector(`#pdf-preview-attachment-splitter-${splitType}`);
      if (hidden) {
        splitContainer.setAttribute("height", "0");
        splitContainer.style.visibility = "hidden";
        splitSplitter.style.visibility = "hidden";
      } else {
        splitContainer.setAttribute("height", this.getSplitHeight());
        splitContainer.style.removeProperty("visibility");
        splitSplitter.style.removeProperty("visibility");
      }
      const hiddenType = splitType === "before" ? "after" : "before";
      const hiddenContainer = document.querySelector(`#pdf-preview-attachment-${hiddenType}`);
      const hiddenSplitter = document.querySelector(`#pdf-preview-attachment-splitter-${hiddenType}`);
      hiddenContainer.setAttribute("height", "0");
      hiddenContainer.style.visibility = "hidden";
      hiddenSplitter.style.visibility = "hidden";
    }
    setSplitHeight(height) {
      Zotero.Prefs.set("pdfpreview.splitHeight", height);
    }
    getSplitHeight() {
      return Zotero.Prefs.get("pdfpreview.splitHeight");
    }
    setSplitCollapsed(collapsed = void 0, quietly = false) {
      if (typeof collapsed === "undefined") {
        collapsed = !this.previewSplitCollapsed;
      }
      if (!quietly) {
        const lastCollapsed = this.previewSplitCollapsed;
        this.previewSplitCollapsed = collapsed;
        if (lastCollapsed && !collapsed) {
          this.doPreview();
        }
      }
      const toCollapseIds = [
        "pdf-preview-infosplit-splitter-before",
        "pdf-preview-infosplit-splitter-after",
        "pdf-preview-attachment-splitter-before",
        "pdf-preview-attachment-splitter-after"
      ];
      toCollapseIds.forEach((_id) => {
        document.getElementById(_id).setAttribute("state", collapsed ? "collapsed" : "open");
      });
    }
    async initPreview(type) {
      var _a;
      console.log("init preview iframe");
      this._Addon.preview._initPromise = Zotero.Promise.defer();
      const { container } = this._Addon.preview.getPreviewElements(type);
      if (!container) {
        return;
      }
      const iframeId = this._Addon.preview.getPreviewIds(type).iframeId;
      (_a = document.getElementById(iframeId)) == null ? void 0 : _a.remove();
      const iframe = document.createElement("iframe");
      iframe.setAttribute("id", iframeId);
      iframe.setAttribute("src", "chrome://PDFPreview/content/previewPDF.html");
      container.appendChild(iframe);
      await this._Addon.preview._initPromise;
      iframe.contentWindow.postMessage({
        type: "updateToolbar",
        previewType: type
      }, "*");
    }
  };
  var events_default = AddonEvents;

  // src/preview.ts
  var Annotation = class {
    constructor(type, position, color, pageLabel) {
      this.type = type;
      this.position = position;
      this.color = color;
      this.pageLabel = pageLabel;
    }
  };
  var RELOAD_COUNT = 10;
  var AddonPreview = class extends module_default {
    constructor(parent) {
      super(parent);
      this._previewCounts = {};
      let type = 1 /* info */;
      while (type !== 4 /* null */) {
        this._previewCounts[type] = 0;
        type++;
      }
    }
    async updatePreviewItem(alwaysUpdate = false) {
      let items = ZoteroPane.getSelectedItems();
      if (items.length !== 1) {
        return false;
      }
      let item = items[0];
      if (item.isRegularItem()) {
        item = await items[0].getBestAttachment();
      }
      console.log(items, item);
      if (!item || !item.isPDFAttachment()) {
        this._Addon.events.setSplitCollapsed(true, true);
        return false;
      } else {
        if (!this._Addon.events.previewSplitCollapsed) {
          this._Addon.events.setSplitCollapsed(false, true);
        }
      }
      if (!alwaysUpdate && this.item && item.id === this.item.id) {
        console.log("Preview skipped for same item");
        this._skipRendering = true;
      } else {
        this._skipRendering = false;
      }
      this.item = item;
      return this.item;
    }
    getPreviewIds(type) {
      let iframeId = "";
      let containerId = "";
      const splitType = Zotero.Prefs.get("pdfpreview.splitType");
      if (type === 1 /* info */) {
        iframeId = `pdf-preview-info-${splitType}-container`;
        containerId = `pdf-preview-infosplit-${splitType}`;
      } else if (type === 2 /* preview */) {
        iframeId = `pdf-preview-preview-container`;
        containerId = "pdf-preview-tabpanel";
      } else if (type === 3 /* attachment */) {
        iframeId = `pdf-preview-attachment-${splitType}-container`;
        containerId = `pdf-preview-attachment-${splitType}`;
      }
      return { iframeId, containerId };
    }
    getPreviewElements(type) {
      const { iframeId, containerId } = this.getPreviewIds(type);
      return {
        iframe: document.getElementById(iframeId),
        container: document.getElementById(containerId)
      };
    }
    updateWidth(type) {
      var _a, _b;
      const iframe = this.getPreviewElements(type).iframe;
      iframe.style.width = "100px";
      const width = (_a = iframe.parentElement) == null ? void 0 : _a.clientWidth;
      if (!width) {
        return;
      }
      iframe.style.width = `${width}px`;
      (_b = iframe.contentWindow) == null ? void 0 : _b.postMessage({
        type: "updateWidth",
        width: width - 40
      }, "*");
    }
    async preview(type, force = false) {
      var _a, _b, _c;
      if (Zotero.Prefs.get("pdfpreview.enable") === false || Zotero.Prefs.get(`pdfpreview.${type === 2 /* preview */ ? "enableTab" : "enableSplit"}`) === false) {
        return;
      }
      if (this._previewCounts[type] >= RELOAD_COUNT) {
        this._previewCounts[type] = 0;
        await this._Addon.events.initPreview(type);
        this._Addon.events.doPreview(true);
        return;
      }
      await this._Addon.preview._initPromise;
      let { iframe } = this.getPreviewElements(type);
      let t = 0;
      while (t < 500 && iframe.contentDocument.readyState !== "complete") {
        await Zotero.Promise.delay(10);
        t += 10;
      }
      let item = await this.updatePreviewItem(type !== this.lastType || ((_a = this.item) == null ? void 0 : _a.id) !== iframe.contentWindow.cachedData.itemID || force);
      console.log(item);
      if (force && !item) {
        item = this.item;
      }
      if (item) {
        if (this._loadingPromise) {
          await this._loadingPromise.promise;
        }
        if (!iframe) {
        }
        iframe.hidden = false;
        iframe.style.width = "100px";
        const width = (_b = iframe.parentElement) == null ? void 0 : _b.clientWidth;
        if (!width) {
          return;
        }
        iframe.style.width = `${width}px`;
        await this._initPromise.promise;
        if (item.id !== this.item.id) {
          return;
        }
        if (this._skipRendering) {
          iframe.hidden = false;
          return;
        }
        console.log("do preview");
        this.lastType = type;
        (_c = iframe.contentWindow) == null ? void 0 : _c.postMessage({
          type: "renderPreview",
          itemID: this.item.id,
          width: width - 40,
          annotations: Zotero.Prefs.get("pdfpreview.showAnnotations") ? item.getAnnotations().map((i) => new Annotation(i.annotationType, JSON.parse(i.annotationPosition), i.annotationColor, i.annotationPageLabel)) : [],
          previewType: type
        }, "*");
        iframe.hidden = false;
      } else {
        console.log("hide preview");
        if (iframe) {
          iframe.hidden = true;
        }
      }
    }
  };
  var preview_default = AddonPreview;

  // src/addon.ts
  var PDFPreview = class {
    constructor() {
      this.events = new events_default(this);
      this.preview = new preview_default(this);
    }
  };
  var addon_default = PDFPreview;

  // src/index.ts
  Zotero.PDFPreview = new addon_default();
  window.addEventListener("load", async function(e) {
    Zotero.PDFPreview.events.onInit();
  }, false);
})();
